<?php
/*
Plugin Name: Sample Admin Page
 */

function cdia_admin_init() {
	register_setting( 'bold-titles', 'bold-titles', 'cdia_sanitize_options' );
}
add_action( 'admin_init', 'cdia_admin_init' );

function cdia_sanitize_options( $data ) {
	$data_sanitized = array();

	if ( is_array( $data ) ) {
		foreach ( $data as $key => $datum ) {
			$data_sanitized[ $key ] = (bool) $datum;
		}
	}

	return $data_sanitized;
}

function cdia_admin_menu() {
	add_theme_page('Bold All The Things', 'Bold Titles', 'manage_options', 'bold-titles', 'cdia_bold_titles_screen');
}
add_action( 'admin_menu', 'cdia_admin_menu' );

function cdia_bold_titles_screen() {
	$options = get_option( 'bold-titles', array( 'all' => false, 'skip-single' => false ) );
	$options = wp_parse_args( $options, array( 'all' => false, 'skip-single' => false ) );
	?>
		<div class="wrap">
			<h2><?php echo get_admin_page_title(); ?></h2>

			<form action="options.php" method="post">
				<?php settings_fields( 'bold-titles' ); ?>
				<table class="form-table">
					<tr>
						<th scope="row">Bold all titles?</th>
						<td><input type="checkbox" name="bold-titles[all]" value="1"<?php checked( true, $options[ 'all' ] ); ?> /></td>
					</tr>
					<tr>
						<th scope="row">Don't bold on single posts?</th>
						<td><input type="checkbox" name="bold-titles[skip-single]" value="1"<?php checked( true, $options[ 'skip-single' ] ); ?> /></td>
					</tr>
				</table>

				<?php submit_button(); ?>
			</form>
		</div>
	<?php
}

function cdia_bold_titles( $title ) {
	if ( is_admin() || ! in_the_loop() )
		return $title;

	$options = get_option( 'bold-titles', array( 'all' => false, 'skip-single' => false ) );
	$options = wp_parse_args( $options, array( 'all' => false, 'skip-single' => false ) );

	$meta = get_post_meta( get_the_ID(), '_do_not_bold_title', true );

	if ( ( is_single() && $options[ 'skip-single' ] ) || $meta )
		return $title;

	if ( $options[ 'all' ] )
		$title = '<em>' . $title . '</em>';

	return $title;
}
add_filter( 'the_title', 'cdia_bold_titles' );


function cdia_register_metabox() {
	add_meta_box( 'bold-titles', 'Bold Titles', 'cdia_bold_titles_metabox', 'post', 'side', 'high' );
}
add_action( 'add_meta_boxes', 'cdia_register_metabox' );

function cdia_bold_titles_metabox( $post ) {
	$bold = get_post_meta( $post->ID, '_do_not_bold_title', true );

	?>
		<p>
			<input type="checkbox" name="bold_title" id="bold-titles-checkbox" value="1"<?php checked( $bold ); ?> />
			<label for="bold-titles-checkbox">Don't display the post title in bold?</label>
		</p>
	<?php
}

function cdia_bold_titles_save( $post_id,  $post ) {
	if ( $post->post_type != 'post' )
		return;

	if ( isset( $_POST[ 'bold_title' ] ) )
		update_post_meta( $post_id, '_do_not_bold_title', 1 );
	else
		delete_post_meta( $post_id, '_do_not_bold_title' );
}
add_action( 'save_post', 'cdia_bold_titles_save', 10, 2 );
